@@ -1,5 +1,6 @@
 from django.apps import AppConfig
 
+from .config import settings
 from .task import auto_convert_commands_to_tasks
 
 
@@ -10,3 +11,4 @@ class DjangoCeleryExtensionsAppConfig(AppConfig):
 
     def ready(self):
         auto_convert_commands_to_tasks()
+        from django_celery_extensions.checks import check_celery_tasks
